<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\KategoriObat;

class KategoriObatController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(!\Helper::hakAkses('Kategori Layanan','View')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $title = "Kategori Layanan";
        $url = "kategori";
        $menu = "Kategori Layanan";

        $kategori = KategoriObat::all();
        return view('kategori.index', compact('title', 'url', 'menu', 'kategori'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!\Helper::hakAkses('Kategori Layanan','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $title = "Kategori Layanan";
        $url = "kategori";
        $menu = "Kategori Layanan";

        return view('kategori.create', compact('title', 'url', 'menu'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(!\Helper::hakAkses('Kategori Layanan','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $this->validate($request, [
            'nama_kategori' => 'required'
        ]);
            
        try {
        $kategori = KategoriObat::create([
            'nama_kategori' => $request->nama_kategori,
        ]);

        \Helper::addUserLog('menambah data Kategori '.$request->nama_kategori,$kategori->toArray());

        return redirect()->route('kategori.index')->with('success', 'Data Berhasil Ditambahkan');

        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!\Helper::hakAkses('Kategori Layanan','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $kategori = KategoriObat::find($id);
        $title = "Kategori Layanan";
        $url = "kategori";
        $menu = "Kategori Layanan";
        
        return view('kategori.edit', compact('title', 'url', 'menu', 'kategori'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(!\Helper::hakAkses('Kategori Layanan','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {
            $kategori = KategoriObat::find($id);
            $old = $kategori->toArray();
            $kategori->update([
                'nama_kategori' => $request->nama_kategori
            ]);

            \Helper::addUserLog('Mengubah Data Obat '.$request->nama_kategori,[
                'old'=>$old,
                'update'=>$kategori->toArray()
            ]);

            return redirect(route('kategori.index'))->with('success', 'Data Berhasil Diubah');
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(!\Helper::hakAkses('Kategori Layanan','Delete')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {    
            $kategori = KategoriObat::find($id);            
            $nama = $kategori->nama_kategori;
            $kategori->delete();
            \Helper::addUserLog('Menghapus Data Obat '.$nama,$kategori->toArray());        
           
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

        return redirect(route('kategori.index'))->with('success', 'Data Berhasil Dihapus');
    }
}
