<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\KategoriObat;
use App\Models\Obat;

class ObatController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if(!\Helper::hakAkses('Layanan','View')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $title = "Layanan";
        $url = "obat";
        $menu = "Layanan";

        $obat = Obat::all();
        return view('obat.index', compact('title', 'url', 'menu', 'obat'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if(!\Helper::hakAkses('Layanan','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        $title = "Layanan";
        $url = "obat";
        $menu = "Layanan";
        $kategori = KategoriObat::all();

        return view('obat.create', compact('title', 'url', 'menu', 'kategori'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(!\Helper::hakAkses('Layanan','Create')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $this->validate($request, [
            'nama_obat' => 'required',
            'keterangan' => 'required',
            'harga' => 'required',
            'kategori_obat_id' => 'required',
        ]);
            
        try {
        $obat = Obat::create([
            'nama_obat' => $request->nama_obat,
            'keterangan' => $request->keterangan,
            'harga' => \Helper::cleanPrice($request->harga),
            'kategori_obat_id' => $request->kategori_obat_id,
        ]);

        \Helper::addUserLog('menambah data Obat '.$request->nama_obat,$obat->toArray());

        return redirect()->route('obat.index')->with('success', 'Data Berhasil Ditambahkan');

        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {

    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        if(!\Helper::hakAkses('Layanan','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }
        
        $obat = Obat::find($id);
        $title = "Layanan";
        $url = "obat";
        $menu = "Layanan";
        $kategori = KategoriObat::all();
        
        return view('obat.edit', compact('title', 'url', 'menu', 'obat', 'kategori'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        if(!\Helper::hakAkses('Layanan','Update')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {
            $obat = Obat::find($id);
            $old = $obat->toArray();
            $obat->update([
                'nama_obat' => $request->nama_obat,
                'harga' => \Helper::cleanPrice($request->harga),
                'keterangan' => $request->keterangan,
                'kategori_obat_id' => $request->kategori_obat_id,
            ]);

            \Helper::addUserLog('Mengubah Data Obat '.$request->nama_obat,[
                'old'=>$old,
                'update'=>$obat->toArray()
            ]);

            return redirect(route('obat.index'))->with('success', 'Data Berhasil Diubah');
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        if(!\Helper::hakAkses('Layanan','Delete')){            
            return redirect()->back()->with('error', 'Anda Tidak Memiliki Hak Akses Untuk Membuka Halaman Ini');
        }

        try {    
            $obat = Obat::find($id);            
            $nama = $obat->nama_obat;
            $obat->delete();
            \Helper::addUserLog('Menghapus Data Obat '.$nama,$obat->toArray());        
           
        } catch (\Throwable $th) {
            return redirect()->back()->with('error', 'Ada Masalah, ' . $th->getMessage())->withInput();
        }

        return redirect(route('obat.index'))->with('success', 'Data Berhasil Dihapus');
    }
}
